# Changelog

## 1.11.0 (2026-02-02)

Full Changelog: [v1.10.1...v1.11.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.10.1...v1.11.0)

### Features

* **api:** api update ([852cb29](https://github.com/DayMoonDevelopment/post-for-me-python/commit/852cb29c19dfe240e7190fe98c4f5381a8916eed))
* **api:** api update ([2f31456](https://github.com/DayMoonDevelopment/post-for-me-python/commit/2f314566f5051317566d9d9182f50de0c84892ad))
* **client:** add custom JSON encoder for extended type support ([c71ec5e](https://github.com/DayMoonDevelopment/post-for-me-python/commit/c71ec5ea2cdcd2c49a63e36de896bf3f17d0603e))


### Bug Fixes

* **docs:** fix mcp installation instructions for remote servers ([fd3b451](https://github.com/DayMoonDevelopment/post-for-me-python/commit/fd3b45115079d4f21abab259705ab1ea7cafa7f8))

## 1.10.1 (2026-01-24)

Full Changelog: [v1.10.0...v1.10.1](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.10.0...v1.10.1)

### Chores

* **ci:** upgrade `actions/github-script` ([9e076a0](https://github.com/DayMoonDevelopment/post-for-me-python/commit/9e076a06afc895a84675e28c7786107efeaf5772))
* **internal:** update `actions/checkout` version ([b893306](https://github.com/DayMoonDevelopment/post-for-me-python/commit/b893306e4e476f5aaeade58b689d14ed50272022))

## 1.10.0 (2026-01-14)

Full Changelog: [v1.9.0...v1.10.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.9.0...v1.10.0)

### Features

* **api:** api update ([02f46bc](https://github.com/DayMoonDevelopment/post-for-me-python/commit/02f46bc1e5a223a724fb900d2e28fc1fa4eac90f))
* **client:** add support for binary request streaming ([f5210a2](https://github.com/DayMoonDevelopment/post-for-me-python/commit/f5210a2a8c749e97a0f250cd807d34edfb9c844a))

## 1.9.0 (2026-01-09)

Full Changelog: [v1.8.0...v1.9.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.8.0...v1.9.0)

### Features

* **api:** api update ([c64cacc](https://github.com/DayMoonDevelopment/post-for-me-python/commit/c64cacc7fd481d300d735ce1a540d63290fc029b))
* **api:** api update ([774a595](https://github.com/DayMoonDevelopment/post-for-me-python/commit/774a595a328fea260b2f95af104f24520880c45d))
* **api:** api update ([46a3c1b](https://github.com/DayMoonDevelopment/post-for-me-python/commit/46a3c1b53620ab0f44b0532c148400e87829c2ef))


### Documentation

* prominently feature MCP server setup in root SDK readmes ([205c722](https://github.com/DayMoonDevelopment/post-for-me-python/commit/205c72259b191067290f9295115ca9ceaebabac2))

## 1.8.0 (2025-12-30)

Full Changelog: [v1.7.0...v1.8.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.7.0...v1.8.0)

### Features

* **api:** Adding account feed endpoint ([6fe6d50](https://github.com/DayMoonDevelopment/post-for-me-python/commit/6fe6d50676b6f4a6f9d5f48a870bbef400930029))

## 1.7.0 (2025-12-19)

Full Changelog: [v1.6.0...v1.7.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.6.0...v1.7.0)

### Features

* **api:** api update ([b10441f](https://github.com/DayMoonDevelopment/post-for-me-python/commit/b10441fbe73159828b922db73a927e7ee4094d5d))
* **api:** api update ([8e3c40e](https://github.com/DayMoonDevelopment/post-for-me-python/commit/8e3c40ed2facc80ed39429a6fb10dd2187020674))
* **api:** api update ([003a675](https://github.com/DayMoonDevelopment/post-for-me-python/commit/003a6752f3a51bbe7866854d138abe1be27251c1))


### Bug Fixes

* ensure streams are always closed ([a171a01](https://github.com/DayMoonDevelopment/post-for-me-python/commit/a171a0112b0faf99b5fc4ad7078a7fbe0608cc02))
* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([89a8bb8](https://github.com/DayMoonDevelopment/post-for-me-python/commit/89a8bb8642ee306aabf34bcc90603db223f820c0))
* use async_to_httpx_files in patch method ([589b159](https://github.com/DayMoonDevelopment/post-for-me-python/commit/589b1591864e46f1809c041a10cbf384c8545a96))


### Chores

* add missing docstrings ([6fa5f8f](https://github.com/DayMoonDevelopment/post-for-me-python/commit/6fa5f8fa84e3413c03da1e221cbeb74c5dcdb69d))
* add Python 3.14 classifier and testing ([3142214](https://github.com/DayMoonDevelopment/post-for-me-python/commit/31422143660cf5f54b09e1b51b0855f4de7b58d5))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([c8696fc](https://github.com/DayMoonDevelopment/post-for-me-python/commit/c8696fcc1ff72c5d8697e0d467dbee1e81e9c791))
* **docs:** use environment variables for authentication in code snippets ([6ad651b](https://github.com/DayMoonDevelopment/post-for-me-python/commit/6ad651bbe10c2c88390f710c1c332b5ad84a08b0))
* **internal:** add `--fix` argument to lint script ([c03c497](https://github.com/DayMoonDevelopment/post-for-me-python/commit/c03c49736ac20dcfb60e4bcc2e56287ddda7a035))
* **internal:** add missing files argument to base client ([69bc0df](https://github.com/DayMoonDevelopment/post-for-me-python/commit/69bc0df9f100c2f28f5205c516cbf436a1b41ecd))
* speedup initial import ([be813dd](https://github.com/DayMoonDevelopment/post-for-me-python/commit/be813dda3e151562ffacb1f8737263823e2b4014))
* update lockfile ([b624e7f](https://github.com/DayMoonDevelopment/post-for-me-python/commit/b624e7f31df287a028c83414bffe346fb20d0849))

## 1.6.0 (2025-11-12)

Full Changelog: [v1.5.0...v1.6.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.5.0...v1.6.0)

### Features

* **api:** api update ([6bc15d2](https://github.com/DayMoonDevelopment/post-for-me-python/commit/6bc15d200226afebd297bdc398b74f6a54ca6a9a))


### Bug Fixes

* **client:** close streams without requiring full consumption ([93f9dc2](https://github.com/DayMoonDevelopment/post-for-me-python/commit/93f9dc2aa7bf9d3da8df93107a74ec96368dbd37))
* compat with Python 3.14 ([c4ed401](https://github.com/DayMoonDevelopment/post-for-me-python/commit/c4ed4019478494d2b9bfd474a6851ca7fa16518b))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([002cbf6](https://github.com/DayMoonDevelopment/post-for-me-python/commit/002cbf67c69e00b7a871f4660ccd6fb2e5e5bf80))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([803870f](https://github.com/DayMoonDevelopment/post-for-me-python/commit/803870fd29b269828428d7cffefac4c64fe8c3c1))
* **internal/tests:** avoid race condition with implicit client cleanup ([bf2dc61](https://github.com/DayMoonDevelopment/post-for-me-python/commit/bf2dc611bc0ef2cf5589764757be4b7cd07ede22))
* **internal:** detect missing future annotations with ruff ([b8bd28f](https://github.com/DayMoonDevelopment/post-for-me-python/commit/b8bd28f2b5b291d5c2f0ca1c7e61633ad2483479))
* **internal:** grammar fix (it's -&gt; its) ([b897bea](https://github.com/DayMoonDevelopment/post-for-me-python/commit/b897bea001d0d9fd1014057c93a162212b384c50))
* **package:** drop Python 3.8 support ([4310a3b](https://github.com/DayMoonDevelopment/post-for-me-python/commit/4310a3b2acf2b53fd87ff12ac466b1185570c5c1))

## 1.5.0 (2025-10-03)

Full Changelog: [v1.4.0...v1.5.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.4.0...v1.5.0)

### Features

* **api:** api update ([11ee33e](https://github.com/DayMoonDevelopment/post-for-me-python/commit/11ee33e297a5547023f1a275d4e5c47e61c875a7))
* **api:** api update ([1f7bc28](https://github.com/DayMoonDevelopment/post-for-me-python/commit/1f7bc28044cb554918c4fffd667d7379538e6ddb))
* **api:** api update ([a6e5319](https://github.com/DayMoonDevelopment/post-for-me-python/commit/a6e53194e5b8460f6446aa8e53d60da9072c2a2b))


### Chores

* do not install brew dependencies in ./scripts/bootstrap by default ([c847232](https://github.com/DayMoonDevelopment/post-for-me-python/commit/c847232c41fc4df1119f7dc6032875425262e5cc))
* **internal:** update pydantic dependency ([feee153](https://github.com/DayMoonDevelopment/post-for-me-python/commit/feee153b47eb97eb2cc24e192dd5a7d074b7668a))
* **types:** change optional parameter type from NotGiven to Omit ([a2e29a6](https://github.com/DayMoonDevelopment/post-for-me-python/commit/a2e29a686feb9a61e208bcf99b7e6e813cac4c42))

## 1.4.0 (2025-09-06)

Full Changelog: [v1.3.2...v1.4.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.3.2...v1.4.0)

### Features

* **api:** api update ([9bf8f24](https://github.com/DayMoonDevelopment/post-for-me-python/commit/9bf8f24fc98784e5b6f921eb6a44c9587e2f96c5))
* improve future compat with pydantic v3 ([4d3284d](https://github.com/DayMoonDevelopment/post-for-me-python/commit/4d3284d053169b65488822ac5670e18fd550451e))
* **types:** replace List[str] with SequenceNotStr in params ([8610c17](https://github.com/DayMoonDevelopment/post-for-me-python/commit/8610c1757bd442d5b9c0aa9b3a956780265f2923))


### Chores

* **internal:** move mypy configurations to `pyproject.toml` file ([708524d](https://github.com/DayMoonDevelopment/post-for-me-python/commit/708524d4fbe2701adf3eb3bfee19b0a7b65883c6))
* **tests:** simplify `get_platform` test ([bae6cdd](https://github.com/DayMoonDevelopment/post-for-me-python/commit/bae6cddec04ea04eb60829df7f758d0978778915))

## 1.3.2 (2025-09-01)

Full Changelog: [v1.3.1...v1.3.2](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.3.1...v1.3.2)

### Chores

* **internal:** add Sequence related utils ([94bd093](https://github.com/DayMoonDevelopment/post-for-me-python/commit/94bd093d74c2cdb4e4e60eaaeae932480460c92a))

## 1.3.1 (2025-08-27)

Full Changelog: [v1.3.0...v1.3.1](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.3.0...v1.3.1)

### Bug Fixes

* avoid newer type syntax ([661702e](https://github.com/DayMoonDevelopment/post-for-me-python/commit/661702eaaba92300e23fb8e51a1be1e7947e7334))


### Chores

* **internal:** change ci workflow machines ([a6439a8](https://github.com/DayMoonDevelopment/post-for-me-python/commit/a6439a8669521cd4bcc0cba15bedacd5ef3c57bd))
* **internal:** update pyright exclude list ([f16087e](https://github.com/DayMoonDevelopment/post-for-me-python/commit/f16087ebe62442d3dabac24fb00c08fed940c6df))

## 1.3.0 (2025-08-23)

Full Changelog: [v1.2.0...v1.3.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.2.0...v1.3.0)

### Features

* **api:** api update ([4df930e](https://github.com/DayMoonDevelopment/post-for-me-python/commit/4df930e52adb15b936da8904ef96cc4bad0eb514))
* **api:** api update ([6ea412d](https://github.com/DayMoonDevelopment/post-for-me-python/commit/6ea412d4d3d1a55b72ad469c8d581022412e51fb))
* **api:** manual updates ([2701154](https://github.com/DayMoonDevelopment/post-for-me-python/commit/2701154f62b4737d3627857402274ae651a4c887))
* **api:** manual updates ([32e52f7](https://github.com/DayMoonDevelopment/post-for-me-python/commit/32e52f7e35b0ab14ac1e7bd0f2b7a17c9cc9e59f))

## 1.2.0 (2025-08-22)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.1.0...v1.2.0)

### Features

* **api:** api update ([150ee93](https://github.com/DayMoonDevelopment/post-for-me-python/commit/150ee93ecb5e62f045ac04e08aad624c07ae5cf6))


### Chores

* update github action ([ed866c4](https://github.com/DayMoonDevelopment/post-for-me-python/commit/ed866c48e9898609bad238f2d47aa1e4e125a804))

## 1.1.0 (2025-08-18)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v1.0.0...v1.1.0)

### Features

* **api:** api update ([9c37a21](https://github.com/DayMoonDevelopment/post-for-me-python/commit/9c37a21cb008f41f2be8dfff0f9bf6e12d4ba865))

## 1.0.0 (2025-08-14)

Full Changelog: [v0.1.0-alpha.2...v1.0.0](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v0.1.0-alpha.2...v1.0.0)

### Chores

* update SDK settings ([b8082a0](https://github.com/DayMoonDevelopment/post-for-me-python/commit/b8082a090eed686047e8cda9fd4dcfaaf3416b23))

## 0.1.0-alpha.2 (2025-08-14)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([2331d12](https://github.com/DayMoonDevelopment/post-for-me-python/commit/2331d12316376fdb84e82636557c69817086503f))

## 0.1.0-alpha.1 (2025-08-13)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/DayMoonDevelopment/post-for-me-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **mcp:** add logging when environment variable is set ([fa3729c](https://github.com/DayMoonDevelopment/post-for-me-python/commit/fa3729cc7dc412da64ab91400c650fde2029ff77))
* **mcp:** add unix socket option for remote MCP ([ad469be](https://github.com/DayMoonDevelopment/post-for-me-python/commit/ad469bed8e16928a828eb71ba7a4f25f85a25964))
* **mcp:** remote server with passthru auth ([4a1e7fa](https://github.com/DayMoonDevelopment/post-for-me-python/commit/4a1e7fa1254405fb350e3cc5643d7cad6bf7025c))


### Bug Fixes

* **mcp:** avoid sending `jq_filter` to base API ([2ccea1a](https://github.com/DayMoonDevelopment/post-for-me-python/commit/2ccea1a536b05eff112d3c497706b7b5b6f2c5f9))
* **mcp:** fix bug in header handling ([f141333](https://github.com/DayMoonDevelopment/post-for-me-python/commit/f14133320050d375f57364c0b5bb6cfacd6bed06))
* **mcp:** fix tool description of jq_filter ([f485355](https://github.com/DayMoonDevelopment/post-for-me-python/commit/f4853557d14c308bbaa601eb41be0b9958b39db3))
* **mcp:** reverse validJson capability option and limit scope ([4a94629](https://github.com/DayMoonDevelopment/post-for-me-python/commit/4a946292e376954b1ffa7e49ebac76bd1377de11))


### Chores

* configure new SDK language ([31eba50](https://github.com/DayMoonDevelopment/post-for-me-python/commit/31eba503379b0175413bfc7508ef48cef614026b))
* **internal:** codegen related update ([42995ab](https://github.com/DayMoonDevelopment/post-for-me-python/commit/42995ab9247b644c924a7bb50f1b5c4f85b588e4))
* **internal:** move publish config ([146d645](https://github.com/DayMoonDevelopment/post-for-me-python/commit/146d645cfd3ef265d1adcc63486896da68196c3f))
* **internal:** update comment in script ([b70ff74](https://github.com/DayMoonDevelopment/post-for-me-python/commit/b70ff74f4651a5c71a2cf74bf9623c0a93aefb39))
* **mcp:** refactor streamable http transport ([a9f6624](https://github.com/DayMoonDevelopment/post-for-me-python/commit/a9f662465981111532a99a7bc0054c93b1d543e4))
* remove custom code ([2f2e25c](https://github.com/DayMoonDevelopment/post-for-me-python/commit/2f2e25c7d7d1aa0761f0420495fe8748ed6b67f6))
* update @stainless-api/prism-cli to v5.15.0 ([32be444](https://github.com/DayMoonDevelopment/post-for-me-python/commit/32be44479fb81de291c4a2dbc62fc35c64f82bc7))
